@@ -14,7 +14,7 @@ use English qw/ -no_match_vars /;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('0.1.2');
+our $VERSION = version->new('0.1.3');
 our $NAME    = 'edit';
 our $OPTIONS = [
     'test|T!',
@@ -61,13 +61,21 @@ sub auto_complete {
     eval {
         my $helper = $self->config->get->{editor}{helper_autocomplete};
         if ($helper) {
-            $helper = eval $helper;  ## no critic
-            push @files, $helper->($auto, $self->options->files);
+            my $helper_sub = eval $helper;  ## no critic
+            if ($helper_sub) {
+                push @files, $helper_sub->($auto, $self->options->files);
+            }
+            elsif ($@) {
+                warn "Errored parsing '$@':\n$helper\n";
+            }
+            else {
+                warn "Unknown error with helper sub\n";
+            }
         }
         1;
     } or do { warn $@ };
 
-    print join ' ', grep { $env ne 'edit' ? /^$env/xms : 1 } @files;
+    print join ' ', grep { $env ne 'vtide' && $env ne 'edit' ? /^$env/xms : 1 } @files;
 
     return;
 }
@@ -82,7 +90,7 @@ App::VTide::Command::Edit - Run an edit command (like Run but without a terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Edit version 0.1.2
+This documentation refers to App::VTide::Command::Edit version 0.1.3
 
 =head1 SYNOPSIS
 
