@@ -18,7 +18,7 @@ use File::chdir;
 
 extends 'App::VTide::Command';
 
-our $VERSION = version->new('0.1.2');
+our $VERSION = version->new('0.1.3');
 our $NAME    = 'run';
 our $OPTIONS = [
     'name|n=s',
@@ -274,7 +274,7 @@ sub load_env {
 sub runit {
     my ( $self, @cmd ) = @_;
 
-    print join ' ', @cmd, "\n" if $self->defaults->{test} || $self->defaults->{verbose};
+    print +(join " \\\n  ", @cmd), "\n" if $self->defaults->{test} || $self->defaults->{verbose};
 
     return if $self->defaults->{test};
 
@@ -316,7 +316,7 @@ App::VTide::Command::Run - Run a terminal command
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Run version 0.1.2
+This documentation refers to App::VTide::Command::Run version 0.1.3
 
 =head1 SYNOPSIS
 
